@@ -12,7 +12,7 @@ use Sys::Syslog qw(:macros);
 use LISM::Storage;
 use Data::Dumper;
 
-our $VERSION = '2.1.6';
+our $VERSION = '2.1.7';
 
 our $lism_master = 'lism_master';
 our $syncrdn = 'cn=sync';
@@ -1397,7 +1397,7 @@ sub _getSyncInfo
                                     next;
                                 }
 
-                                $pvals =~ s/([.*+?\[\]])/\\$1/g;
+                                $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ /^$pvals$/i && $ops{modify}) {
                                     $nosync_data{$dname} = 1;
                                     $nosync_entries{lc($dn)} = 1;
@@ -1528,7 +1528,7 @@ sub _getSyncInfo
                                     next;
                                 }
 
-                                $pvals =~ s/([.*+?\[\]])/\\$1/g;
+                                $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ /^$pvals$/i && $ops{modify}) {
                                     $nosync_data{$dname} = 1;
                                     $nosync_entries{lc($dn)} = 1;
@@ -1752,7 +1752,7 @@ sub _setSyncInfo
                                     next;
                                 }
 
-                                $pvals =~ s/([.*+?\[\]])/\\$1/g;
+                                $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ m/^$pvals$/i && $ops{modify}) {
                                     if (!$pocs) {
                                         # Add objectClass for adding new attribute
@@ -1946,7 +1946,7 @@ sub _setSyncInfo
                                     next;
                                 }
 
-                                $pvals =~ s/([.*+?\[\]])/\\$1/g;
+                                $pvals =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                                 if ($dvals !~ m/^$pvals$/i) {
                                     if (@{$left_vals}) {
                                         push(@sync_vals, @{$left_vals});
