@@ -342,7 +342,7 @@ sub add
 
     # check rdn's value
     my ($rdn, $rdn_val) = ($dn =~ /^([^=]+)=([^,]+),/);
-    $rdn_val =~ s/([.*+?\[\]()])/\\$1/g;
+    $rdn_val =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
     if ($entryStr !~ /^$rdn: $rdn_val$/mi) {
         return LDAP_NAMING_VIOLATION;
     }
