@@ -234,7 +234,7 @@ sub _objModify
     my $rc = LDAP_SUCCESS;
 
     my ($rdn_val) = ($dn =~ /^[^=]+=([^,]+),/);
-    $rdn_val =~ s/([.*+?\[\]])/\\$1/g;
+    $rdn_val =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
 
     # multibyte string
     $rdn_val = encode($conf->{mbcode}[0], $rdn_val);
@@ -338,7 +338,7 @@ sub _objModify
                     # check whether the value already exists
                     for (my $i = 0; $i < @values; $i++) {
                         my $value = $values[0];
-                        $value =~ s/([.*+?\[\]])/\\$1/g;
+                        $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                         if ("$valdlm$data[$coln]$valdlm" =~ /$valdlm *$value *$valdlm/i) {
                             $rc = LDAP_TYPE_OR_VALUE_EXISTS;
                             last DO;
@@ -354,7 +354,7 @@ sub _objModify
                         # check whether the value exists
                         for (my $i = 0;  $i < @values; $i++) {
                             my $value = $values[0];
-                            $value =~ s/([.*+?\[\]])/\\$1/g;
+                            $value =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
                             if ("$valdlm$data[$coln]$valdlm" =~ /$valdlm *$value *$valdlm/i) {
                                 my $str = "$valdlm$data[$coln]$valdlm";
                                 $str =~ s/$valdlm$value$valdlm/$valdlm/i;
@@ -409,7 +409,7 @@ sub _objAdd
     my $rc = LDAP_SUCCESS;
 
     my ($rdn_val) = ($dn =~ /^[^=]+=([^,]+),/);
-    $rdn_val =~ s/([.*+?\[\]])/\\$1/g;
+    $rdn_val =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
 
     # multibyte string
     $rdn_val = encode($conf->{mbcode}[0], decode('utf8', $rdn_val));
@@ -543,7 +543,7 @@ sub _objDelete
     my $rc = LDAP_NO_SUCH_OBJECT;
 
     my ($rdn_val) = ($dn =~ /^[^=]+=([^,]+),/);
-    $rdn_val =~ s/([.*+?\[\]])/\\$1/g;
+    $rdn_val =~ s/([.*+?\[\]()|\^\$\\])/\\$1/g;
 
     # multibyte string
     $rdn_val = encode($conf->{mbcode}[0], decode('utf8', $rdn_val));
