@@ -475,6 +475,10 @@ sub _getConnect
         my $msg = $self->{ldap}->bind($conf->{binddn}[0], password => $conf->{bindpw}[0]);
         if ($msg->code) {
             $self->log(level => 'error', message => "Connection check failed");
+            $self->{ldap}->unbind();
+            $self->{bind}->unbind();
+            undef($self->{ldap});
+            undef($self->{bind});
         } else {
             return 0;
         }
